@@ -5,26 +5,24 @@ is_windows <- function() .Platform$OS.type == "windows"
 is_macos <- function() unname(Sys.info()["sysname"] == "Darwin")
 is_linux <- function() unname(Sys.info()["sysname"] == "Linux")
 
-ensure_config <- function(bin_full_path, sep, user_path) {
-  gnparser_path <- dirname(bin_full_path)
-
-  if (!exec_exists(bin_full_path)) rgnparser::install_gnparser()
-
-  Sys.setenv(PATH = paste0(user_path, sep, gnparser_path))
+test_gnparser_setup <- function(bin_full_path){
+  
+  if (!exec_exists(bin_full_path)) message("GNparser is not installed in your machine.")
 }
 
-setup_gnparser <- function() {
-  user_path <- Sys.getenv("PATH")
-
+check_gnparser_setup <- function(){
+  
   if (is_windows() && !bin_on_path() && !bin_exec()) {
-    ensure_config(paste0(Sys.getenv("APPDATA"), "\\gnparser\\gnparser.exe"), ";", user_path)
-  } else if (is_macos() && !bin_on_path() && !bin_exec()) {
-    ensure_config(normalizePath("~/Library/Application Support/gnparser"), ":", user_path)
-  } else if (is_linux() && !bin_on_path() && !bin_exec()) {
-    ensure_config(normalizePath("~/bin/gnparser"), ":", user_path)
-  }
+      test_gnparser_setup(paste0(Sys.getenv("APPDATA"), "\\gnparser\\gnparser.exe"))
+    } else if (is_macos() && !bin_on_path() && !bin_exec()) {
+      test_gnparser_setup(normalizePath("~/Library/Application Support/gnparser"))
+    } else if (is_linux() && !bin_on_path() && !bin_exec()) {
+      test_gnparser_setup(normalizePath("~/bin/gnparser"))
+    }
+  
 }
 
+
 #' Clean and parse scientific names
 #'
 #' This function is composed of a series of name-checking routines for cleaning
@@ -37,6 +35,8 @@ setup_gnparser <- function() {
 #' capitalize only the first letter of the genus name and remove extra
 #' whitespaces), and 5) parse names, i.e., separate author, date, annotations
 #' from taxon name.
+#' 
+
 #'
 #' @family taxonomy
 #' @param sci_names character string. Containing scientific names.
@@ -44,9 +44,7 @@ setup_gnparser <- function() {
 #'
 #' @details Terms denoting uncertainty or provisional status of taxonomic
 #' identification as well as infraspecific terms were obtained from Sigoviniet
-#' al. (2016; doi: 10.1111/2041-210X.12594). More details about the names
-#' parse process can be found in
-#' \href{https://github.com/gnames/gnparser}{gnparser}.
+#' al. (2016; doi: 10.1111/2041-210X.12594).
 #'
 #' @return A five-column data.frame including
 #' * scientificName: original names supplied
@@ -85,16 +83,14 @@ setup_gnparser <- function() {
 #'
 #' bdc_clean_names(scientificName, save_outputs = FALSE)
 #' }
+#' 
 bdc_clean_names <- function(sci_names, save_outputs = FALSE) {
   value <- scientificName <- X1 <- value <- . <- temp <- canonicalfull <- NULL
   cardinality <- quality <- verbatim <- id <- . <- .uncer_terms <- . <- NULL
   .infraesp_names <- names_clean <- NULL
 
-  # one-time setup to download and install rgnparser, which is used to parse
-  # scientific name (for more details, see
-  # https://github.com/ropensci/rgnparser)
-  setup_gnparser()
-
+  # Chech if gnparser is installed. Otherwise, guide user about installation.
+  check_gnparser_setup()
   # names raw
   names_raw <-
     sci_names %>%
@@ -164,7 +160,7 @@ bdc_rem_family_names <- function(data, sci_names) {
     system.file("extdata", "family_names/animalia_families.txt",
       package = "bdc"
     ) %>%
-    readr::read_csv(col_names = F, show_col_types = FALSE) %>%
+    readr::read_csv(col_names = FALSE, show_col_types = FALSE) %>%
     dplyr::tibble() %>%
     dplyr::pull(X1)
 
