@@ -28,14 +28,14 @@
 #' database_id <- c("test_1", "test_2", "test_3", "test_4", "test_5")
 #' .missing_names <- c(TRUE, TRUE, TRUE, FALSE, FALSE)
 #' .missing_coordinates <- c(TRUE, FALSE, FALSE, TRUE, FALSE)
-#' .invalid_basis_of_records <- c(TRUE, TRUE, TRUE, TRUE, TRUE)
+#' .basisOfRecords_notStandard <- c(TRUE, TRUE, FALSE, TRUE, TRUE)
 #' .summary <- c(TRUE, FALSE, FALSE, FALSE, FALSE)
 #'
 #' x <- data.frame(
 #'   database_id,
 #'   .missing_names,
 #'   .missing_coordinates,
-#'   .invalid_basis_of_records,
+#'   .basisOfRecords_notStandard,
 #'   .summary
 #' )
 #'
@@ -65,6 +65,21 @@ bdc_create_report <-
     match.arg(arg = workflow_step,
               choices = c("prefilter", "taxonomy", "space", "time"))
     
+    temp <- data %>% dplyr::select(tidyselect::starts_with("."))
+    
+    if (workflow_step %in% c("prefilter", "space", "time")) {
+      if (all((colSums(temp, na.rm = TRUE) - nrow(temp)) == 0)) {
+        stop("Report was not created.\nNo records flagged as 'FALSE' in test columns starting with '.'")
+      }
+      
+      if (ncol(temp) == 0) {
+        stop(
+          "Report was not created.\nAt least one column 'starting with '.' containing results of data-quality tests must be provided"
+        )
+      }
+    }
+
+    
     # prefilter
     if (workflow_step == "prefilter") {
       tests <-
@@ -72,15 +87,17 @@ bdc_create_report <-
           ".scientificName_empty",
           ".coordinates_empty",
           ".coordinates_outOfRange",
-          ".invalid_basis_of_records",
-          ".coordinates_country_inconsistent",
-          ".summary"
+          ".basisOfRecords_notStandard",
+          ".coordinates_country_inconsistent"
         )
       
       names_tab <- names(data)
       col_to_tests <- dplyr::intersect(tests, names_tab)
       
-      if (file.exists("Output/Check/01_coordinates_transposed.csv")) {
+      has_file <- file.exists("Output/Check/01_coordinates_transposed.csv")
+      has_column <- "coordinates_transposed" %in% names(data)
+      
+      if (has_file & has_column) {
         col_to_tests <- c(col_to_tests, "coordinates_transposed")
       }
     }
@@ -98,8 +115,7 @@ bdc_create_report <-
           ".inst",
           ".dpl",
           ".rou",
-          ".urb",
-          ".summary"
+          ".urb"
         )
       
       names_tab <- names(data)
@@ -110,8 +126,7 @@ bdc_create_report <-
     if (workflow_step == "time") {
       tests <-
         c(".eventDate_empty",
-          ".year_outOfRange",
-          ".summary")
+          ".year_outOfRange")
       
       names_tab <- names(data)
       col_to_tests <- dplyr::intersect(tests, names_tab)
@@ -172,8 +187,9 @@ bdc_create_report <-
         if ("prefilter" %in% workflow_step) {
           pf <-
             data %>%
-            dplyr::select(tidyselect::starts_with(".")) %>%
-            dplyr::select(col_to_tests) %>%
+            # dplyr::select(tidyselect::starts_with(".")) %>%
+            dplyr::select(all_of(col_to_tests)) %>%
+            bdc::bdc_summary_col() %>% 
             dplyr::mutate_if(is.character, ~ as.logical(as.character(.))) %>%
             dplyr::summarise_all(., .funs = sum) %>%
             t() %>%
@@ -217,6 +233,11 @@ bdc_create_report <-
                 Description == ".summary",
                 "Summary of all tests",
                 Description
+              ),
+              Description = dplyr::if_else(
+                Description == "coordinates_transposed",
+                "Records with transposed geographic coordinates",
+                Description
               )
             )
           
@@ -254,7 +275,10 @@ bdc_create_report <-
               dplyr::mutate(notes = ifelse(notes == "FALSE", "taxo_uncer", notes))
           }
           
-          names <- dplyr::bind_rows(names, taxo_unc)
+          if(nrow(taxo_unc > 0)){
+            names <- dplyr::bind_rows(names, taxo_unc)
+          }
+
           names$notes <- stringr::str_squish(names$notes)
           
           names <-
@@ -360,7 +384,7 @@ bdc_create_report <-
         if ("space" %in% workflow_step) {
           space <-
             data %>%
-            dplyr::select(tidyselect::starts_with(".")) %>%
+            # dplyr::select(tidyselect::starts_with(".")) %>%
             dplyr::select(col_to_tests) %>%
             dplyr::mutate_if(is.character, ~ as.logical(as.character(.))) %>%
             dplyr::summarise_all(., .funs = sum) %>%
@@ -447,8 +471,9 @@ bdc_create_report <-
         if ("time" %in% workflow_step) {
           date <-
             data %>%
-            dplyr::select(tidyselect::starts_with(".")) %>%
-            dplyr::select(col_to_tests) %>%
+            # dplyr::select(tidyselect::starts_with(".")) %>%
+            dplyr::select(all_of(col_to_tests)) %>%
+            bdc::bdc_summary_col() %>% 
             dplyr::mutate_if(is.character, ~ as.logical(as.character(.))) %>%
             dplyr::summarise_all(., .funs = sum) %>%
             t() %>%
@@ -494,13 +519,15 @@ bdc_create_report <-
       })
     })
     
-    message(
-      paste(
-        "\nbdc_create_report:\nCheck the report summarizing the results of the",
-        workflow_step,
-        "in:\nOutput/Report\n"
+    if (save_report) {
+      message(
+        paste(
+          "\nbdc_create_report:\nCheck the report summarizing the results of the",
+          workflow_step,
+          "in:\n",here::here("Output", "Report")
+        )
       )
-    )
+    }
     
     return(data)
   }
