@@ -9,6 +9,7 @@
 #' @importFrom dplyr distinct arrange rename mutate pull filter select left_join
 #' @importFrom stringi stri_trans_general
 #' @importFrom stringr str_replace_all str_trim
+#' @importFrom stats na.omit
 #' 
 #' @noRd
 #' @return Return a data.frame with original country names, suggested names and
@@ -22,18 +23,20 @@ bdc_standardize_country <-
            country,
            country_names_db) {
     .data <- names_in_different_languages <- english_name <- lower_case <- NULL
-    cntr_suggested2 <- cntr_suggested <- cntr_iso2c <- alpha2 <- cntr_original2 <- NULL
+    cntr_suggested2 <- cntr_suggested <- cntr_iso2c <- alpha2 <- alpha3 <- cntr_original2 <- NULL
+    . <- NULL
 
     # Create a country database based on occ database
     cntr_db <-
       data %>%
-      dplyr::distinct(.data[[country]], .keep_all = FALSE) %>%
-      dplyr::arrange(.data[[country]]) %>%
-      dplyr::rename(cntr_original = .data[[country]])
-
+      dplyr::distinct(country, .keep_all = FALSE) %>%
+      dplyr::rename(cntr_original = country)
+    
     cntr_db$cntr_original2 <-
-      stringr::str_replace_all(cntr_db$cntr_original, "[[:punct:]]", " ") %>%
+      gsub("&", "and", cntr_db$cntr_original) %>% 
+      stringr::str_replace_all(., "[[:punct:]]", " ") %>%
       stringr::str_trim() %>%
+      stringr::str_squish() %>%
       stringi::stri_trans_general("Latin-ASCII") %>%
       tolower()
 
@@ -43,7 +46,10 @@ bdc_standardize_country <-
     country_names_db <-
       country_names_db %>%
       dplyr::mutate(lower_case = names_in_different_languages %>%
-        stringi::stri_trans_general("Latin-ASCII") %>%
+                      stringr::str_replace_all(., "[[:punct:]]", " ") %>%
+                      stringr::str_trim() %>%
+                      stringr::str_squish() %>% 
+                      stringi::stri_trans_general("Latin-ASCII") %>%
         tolower())
 
     cn <-
@@ -66,10 +72,68 @@ bdc_standardize_country <-
       }
     }
 
+    # Check alpha2 ISO names
+    cn <-
+      country_names_db %>%
+      dplyr::distinct(alpha2) %>%
+      dplyr::pull(1) %>% stats::na.omit()
+    
+    if(any(cn %in% cntr_db$cntr_original)){
+      for (i in 1:length(cn)) {
+        country_names_db_name <-
+          country_names_db %>%
+          dplyr::filter(alpha2 == cn[i]) %>%
+          dplyr::pull(alpha2)
+        
+        filt <-
+          which(tolower(cntr_db$cntr_original2) %in% tolower(country_names_db_name))
+        
+        
+        if (length(filt) > 0) {
+          cnnn <- country_names_db %>%
+            dplyr::filter(alpha2 == cn[i]) %>%
+            dplyr::pull(english_name)
+          cnnn <- cnnn[1]
+          message("country found based on iso2: ", cnnn)
+          cntr_db$cntr_suggested[filt] <- cnnn
+        }
+      }
+    }
+    
+    
+    # Check alpha3 ISO names
+    cn <-
+      country_names_db %>%
+      dplyr::distinct(alpha3) %>%
+      dplyr::pull(1) %>% stats::na.omit()
+    if(any(cn %in% cntr_db$cntr_original)){
+      for (i in 1:length(cn)) {
+        country_names_db_name <-
+          country_names_db %>%
+          dplyr::filter(alpha3 == cn[i]) %>%
+          dplyr::pull(alpha3)
+        
+        filt <-
+          which(tolower(cntr_db$cntr_original2) %in% tolower(country_names_db_name))
+        
+        
+        if (length(filt) > 0) {
+          cnnn <- country_names_db %>%
+            dplyr::filter(alpha3 == cn[i]) %>%
+            dplyr::pull(english_name)
+          cnnn <- cnnn[1]
+          message("country found based on iso3: ", cnnn)
+          cntr_db$cntr_suggested[filt] <- cnnn
+        }
+      }
+    }
+    
+    
     # Standardization of all names founds in cntr_suggested2 fuzzy_d 1
     cntr_db$cntr_suggested[is.na(cntr_db$cntr_suggested)] <-
       bdc_stdz_cntr(cntry_n = cntr_db$cntr_original2[is.na(cntr_db$cntr_suggested)], 
                     country_names_db=country_names_db, fuzzy_d = 1) #NEW version
+    
     # Standardization of all names founds in cntr_suggested2 fuzzy_d 2
     cntr_db$cntr_suggested[is.na(cntr_db$cntr_suggested)] <-
       bdc_stdz_cntr(cntry_n = cntr_db$cntr_original2[is.na(cntr_db$cntr_suggested)], 
@@ -119,6 +183,10 @@ bdc_standardize_country <-
       cntr_db %>%
       dplyr::select(-cntr_original2, -cntr_suggested) %>%
       dplyr::rename(cntr_suggested = cntr_suggested2)
-
+    
+    cntr_db[cntr_db$cntr_original %in% 0:9, 2:3] <- NA
+    
+    cntr_db <- cntr_db %>%
+      dplyr::arrange(cntr_suggested)
     return(cntr_db)
   }
