@@ -1,4 +1,4 @@
 library(testthat)
 library(bdc)
 
-#test_check("bdc")
+test_check("bdc")
