@@ -1,3 +1,6 @@
+skip_on_ci()
+skip_on_cran()
+
 database_id <- c("GBIF_01", "GBIF_02", "GBIF_03", "FISH_04", "FISH_05")
  lat <- c(-19.93580, -13.01667, -22.34161, -6.75000, -15.15806)
  lon <- c(-40.60030, -39.60000, -49.61017, -35.63330, -39.52861)
